==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebPageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageEventArgsDetailDescriptionMetadata } from "./WebPageEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDescription } from "./WebPageEventArgsDescription";
/**
 * @hidden
 */
var WebPageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPageEventArgsDescriptionMetadata, _super);
    function WebPageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageEventArgsDescriptionMetadata.b = function (a) {
        if (WebPageEventArgsDescriptionMetadata.a == null) {
            WebPageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageEventArgsDescriptionMetadata.c(WebPageEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPageEventArgsDescriptionMetadata.a);
        WebPageEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPageEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PageEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebPageEventArgsDetail");
    };
    WebPageEventArgsDescriptionMetadata.d = function (a) {
        WebPageEventArgsDescriptionMetadata.b(a);
        a.aa("WebPageEventArgs", function () { return new WebPageEventArgsDescription(); });
        a.z("WebPageEventArgs", WebPageEventArgsDescriptionMetadata.a);
    };
    WebPageEventArgsDescriptionMetadata.$t = markType(WebPageEventArgsDescriptionMetadata, 'WebPageEventArgsDescriptionMetadata');
    WebPageEventArgsDescriptionMetadata.a = null;
    return WebPageEventArgsDescriptionMetadata;
}(Base));
export { WebPageEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPageEventArgsDetailDescriptionMetadata } from "./WebPageEventArgsDetailDescriptionMetadata";
import { WebPageEventArgsDescription } from "./WebPageEventArgsDescription";
/**
 * @hidden
 */
var WebPageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPageEventArgsDescriptionMetadata, _super);
    function WebPageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPageEventArgsDescriptionMetadata.b = function (a) {
        if (WebPageEventArgsDescriptionMetadata.a == null) {
            WebPageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPageEventArgsDescriptionMetadata.c(WebPageEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPageEventArgsDescriptionMetadata.a);
        WebPageEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPageEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PageEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPageEventArgsDetail");
    };
    WebPageEventArgsDescriptionMetadata.d = function (a) {
        WebPageEventArgsDescriptionMetadata.b(a);
        a.ac("WebPageEventArgs", function () { return new WebPageEventArgsDescription(); });
        a.ab("WebPageEventArgs", WebPageEventArgsDescriptionMetadata.a);
    };
    WebPageEventArgsDescriptionMetadata.$t = markType(WebPageEventArgsDescriptionMetadata, 'WebPageEventArgsDescriptionMetadata');
    WebPageEventArgsDescriptionMetadata.a = null;
    return WebPageEventArgsDescriptionMetadata;
}(Base));
export { WebPageEventArgsDescriptionMetadata };
